==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ThisQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisQuarterExpressionDescription } from "./ThisQuarterExpressionDescription";
/**
 * @hidden
 */
export let ThisQuarterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ThisQuarterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (ThisQuarterExpressionDescriptionMetadata.a == null) {
                ThisQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ThisQuarterExpressionDescriptionMetadata.c(ThisQuarterExpressionDescriptionMetadata.a);
            }
            if (a.j(ThisQuarterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(ThisQuarterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            ThisQuarterExpressionDescriptionMetadata.b(a);
            a.aa("ThisQuarterExpression", () => new ThisQuarterExpressionDescription());
            a.z("ThisQuarterExpression", ThisQuarterExpressionDescriptionMetadata.a);
        }
    }
    ThisQuarterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(ThisQuarterExpressionDescriptionMetadata, 'ThisQuarterExpressionDescriptionMetadata');
    ThisQuarterExpressionDescriptionMetadata.a = null;
    return ThisQuarterExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ThisQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisQuarterExpressionDescription } from "./ThisQuarterExpressionDescription";
/**
 * @hidden
 */
export let ThisQuarterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ThisQuarterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (ThisQuarterExpressionDescriptionMetadata.a == null) {
                ThisQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ThisQuarterExpressionDescriptionMetadata.c(ThisQuarterExpressionDescriptionMetadata.a);
            }
            if (a.k(ThisQuarterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(ThisQuarterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            ThisQuarterExpressionDescriptionMetadata.b(a);
            a.ac("ThisQuarterExpression", () => new ThisQuarterExpressionDescription());
            a.ab("ThisQuarterExpression", ThisQuarterExpressionDescriptionMetadata.a);
        }
    }
    ThisQuarterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(ThisQuarterExpressionDescriptionMetadata, 'ThisQuarterExpressionDescriptionMetadata');
    ThisQuarterExpressionDescriptionMetadata.a = null;
    return ThisQuarterExpressionDescriptionMetadata;
})();
